@@ -38,7 +38,12 @@ sub validate
 
 package    # Hide from PAUSE
     WebService::Shippo::Addresses;
-use base ( 'WebService::Shippo::Collection' );
+use base (
+    'WebService::Shippo::Collection',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+);
+
 sub item_class ()       { 'WebService::Shippo::Address' }
 sub collection_class () { __PACKAGE__ }
 
@@ -58,11 +63,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Address - Address class
+WebService::Shippo::Address - Shippo Address class
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 SYNOPIS
 
