@@ -15,7 +15,11 @@ sub item_class ()       { __PACKAGE__ }
 
 package    # Hide from PAUSE
     WebService::Shippo::Parcels;
-use base ( 'WebService::Shippo::Collection' );
+use base (
+    'WebService::Shippo::Collection',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+);
 
 sub item_class ()       { 'WebService::Shippo::Parcel' }
 sub collection_class () { __PACKAGE__ }
@@ -36,11 +40,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Parcel - Parcel class.
+WebService::Shippo::Parcel - Shippo Parcel class.
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 DESCRIPTION
 
