@@ -21,7 +21,10 @@ sub get_shipping_rates
 
 package    # Hide from PAUSE
     WebService::Shippo::Rates;
-use base ( 'WebService::Shippo::Collection' );
+use base (
+    'WebService::Shippo::Collection',
+    'WebService::Shippo::Fetcher',
+);
 
 sub item_class ()       { 'WebService::Shippo::Rate' }
 sub collection_class () { __PACKAGE__ }
@@ -42,11 +45,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Rate - Rate class.
+WebService::Shippo::Rate - Shippo Rate class.
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 DESCRIPTION
 
