@@ -17,7 +17,11 @@ sub item_class ()       { __PACKAGE__ }
 
 package    # Hide from PAUSE
     WebService::Shippo::Refunds;
-use base ( 'WebService::Shippo::Collection' );
+use base (
+    'WebService::Shippo::Collection',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+);
 
 sub item_class ()       { 'WebService::Shippo::Refund' }
 sub collection_class () { __PACKAGE__ }
@@ -39,11 +43,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::CarrierAccount - Refund class
+WebService::Shippo::CarrierAccount - Shippo Refund class
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 DESCRIPTION
 
