@@ -34,7 +34,11 @@ sub get_shipping_label
 }
 package    # Hide from PAUSE
     WebService::Shippo::Transactions;
-use base ( 'WebService::Shippo::Collection' );
+use base (
+    'WebService::Shippo::Collection',
+    'WebService::Shippo::Creator',
+    'WebService::Shippo::Fetcher',
+);
 
 sub item_class ()       { 'WebService::Shippo::Transaction' }
 sub collection_class () { __PACKAGE__ }
@@ -55,11 +59,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo::Transaction - Transaction class.
+WebService::Shippo::Transaction - Shippo Transaction class.
 
 =head1 VERSION
 
-version 0.0.14
+version 0.0.15
 
 =head1 DESCRIPTION
 
