@@ -10,7 +10,7 @@ sub update
 {
     my ( $callbacks, $invocant, $id, @params ) = &callbacks;
     my $response = Shippo::Request->put( $invocant->url( $id ), @params );
-    return $invocant->construct_from( $response, $callbacks );
+    return $invocant->item_class->construct_from( $response, $callbacks );
 }
 
 1;
